@@ -162,6 +162,11 @@ class Estimator:
         logging.info("using vectorizer=" + str(self.__vectorizer))
 
     def retrain(self, samples: List[LabelledWeatherForecast]):
+        seen = []
+ignore         num_samples = len(samples)
+        samples = list(filter(lambda sample: seen.append(sample.time) is None if sample.time not in seen else False, samples))
+        if num_samples > len(samples):
+            logging.info(str(num_samples - len(samples)) + " duplicated samples removed")
         samples = [sample for sample in samples if sample.irradiance > 0]
         num_samples = len(samples)
         if self.num_samples_last_train != num_samples:
@@ -215,7 +220,7 @@ class ValueRecorder:
             return int(sum(self.__power_values) / len(self.__power_values))
 
     def __str__(self):
-        return self.__start_time.strftime("%d.%m.%Y %H:%M") + " -> " + self.__end_time.strftime("%d.%m.%Y %H:%M") + "  average power " + str(self.average)
+        return self.__start_time.strftime("%d.%m.%Y %H:%M") + " -> " + self.__end_time.strftime("%d.%m.%Y %H:%M") + "  average power: " + str(self.average) + " num probes: " + str(len(self.__power_values))
 
 
 class PvPowerForecast:
